# Curveball
## Predicting competition results from growth curves

[![Version](https://img.shields.io/pypi/v/curveball.svg)](https://pypi.org/project/curveball/)
[![License](https://img.shields.io/pypi/l/curveball.svg)](https://pypi.org/project/curveball/)
[![Build Status](https://app.travis-ci.com/yoavram/curveball.svg)](https://magnum.travis-ci.com/yoavram/curveball)
[![Docs](https://img.shields.io/badge/docs-latest-yellow.svg)](https://curveball.yoavram.com)
[![codecov.io](http://codecov.io/github/yoavram/curveball/coverage.svg?branch=master&token=PV0HysT5gx)](http://codecov.io/github/yoavram/curveball?branch=master)

This open-source library and application implement the method described in:

> Ram Y, Dellus-Gur E, Bibi M, Karkare K, Obolski U, Feldman MW, Cooper TF, Berman J, Hadany L. (2019) **Predicting microbial relative growth in a mixed culture from growth curve data.** _Proceedings of the National Academy of Sciences USA_ 

Please see the [documentation](https://curveball.yoavram.com) for more information.
